#!  /usr/local/bin/perl
use strict;
use Socket;
use Getopt::Std;
my ($executable) = ($0 =~ /([^\/]+)$/);
my $USAGE = "usage:$executable [-h] whois.database";
sub USAGE() { return $USAGE};
sub Help() {
print STDERR<<EOP;
$USAGE
    This program will parse the whois ASCII dump and split it into
    text files where the textfile only contains the typelisted.
    h - this message

EOP
}

my %opts;
getopts("h",\%opts);
if (defined $opts{h}) {
    Help();
    exit;
}

foreach my $file (@ARGV) {
print "$file\n";
    if ($file =~ /(\d{8})\.([^\.]+)\.db/) {
	my ($year, $org) = ($1, $2);
	if ($file =~ /gz$/) {
	    open (IN, "zcat $file |");
	} else {
	    open (IN, "<$file");
	}
	my $dir = ".";
	foreach my $d ($year, $org) {
	    $dir .= "/$d";
	    unless (-d $dir) {
		mkdir ($dir, 0774);
	    }
	}
	Process($dir);
    }
    close IN;
}

sub Process{
    my ($dir) = @_;
    my %type2handler;
    while (<IN>) {
	next if (/#/);
	next if (/^$/);

	if (/^([^:]+):\s+(.+)/) {
	    my ($type,$value) = ($1,$2);
	    my $handler = $type2handler{$type};
	    unless (defined $handler) {
		my $file = "$dir/$type";
		print "opening $file\n";
		open ($handler,">>$file") || die("Unable to open `$type':$!");
		$type2handler{$type} = $handler;
	    }
	    print $handler $_;
	    while (<IN>) {
		print $handler $_;
		last if (/^$/);
	    }
	}
    }
}
